# 概括
这是一个自己总结的常用的python库
安装地址为:
    pip install -i https://test.pypi.org/simple/ zq-python
    或
    pip install zq-python
    若是更新
    pip install zq-python update



## 说明
本包名字为*zq-python*,使用方法包括...
version:0.1.0
self.LogD = Log.LogD
self.LogW = Log.LogW
self.LogE = Log.LogE

self.File = FileServiceClass()
self.Http = HttpServiceClass()
self.Regex = RegexServiceClass()
self.Thread = ThreadServiceClass()
self.Time = TimeServiceClass()
self.VideoDownload = VideoDownloadServiceClass()
self.Localize = LocallizeServiceClass(path=kwargs.get("LocallizePath", None))
self.WaitExecutService = WaitExecutServiceClass()

self.QrCodeService = QrCodeServiceClass()

self.ToolsService = ToolsServiceClass()

self.MailService = MailServiceClass()

### 打包方法

### 安装方法

### 参数说明

### 错误反馈